@@ -1,17 +1,20 @@
-import enum
 import ast
 from ast import parse
 import codecs
 import dataclasses as dc
 import difflib
+import enum
+from functools import partial
 import importlib
 import io
+from multiprocessing import Pool
 import os
 import re
 import sys
 import time
 from typing import Any
 from typing import Iterable
+from typing import Iterator
 from typing import List
 from typing import NamedTuple
 from typing import Optional
@@ -185,6 +188,11 @@ class Rewriter:
             rewritten, type_check_pass=RewritePass.PLAIN
         )
 
+        if self.options.black_line_length:
+            rewritten = list(
+                _mini_black_format(rewritten, self.options.black_line_length)
+            )
+
         differ = list(difflib.Differ().compare(self.source_lines, rewritten))
 
         self.stats["added"] = len([l for l in differ if l.startswith("+ ")])
@@ -197,10 +205,10 @@ class Rewriter:
 
 
 class TypeCheckingBlocks:
-    def __init__(self, source_lines, type):
+    def __init__(self, source_lines, type_):
         self.type_checking_blocks = []
         self.anti_type_checking_blocks = []
-        self.type = type
+        self.type = type_
 
         in_type_checking_block = False
         in_anti_type_checking_block = False
@@ -781,12 +789,30 @@ def sort_imports(style: Any, imports: List[ClassifiedImport], options: Any):
     return sorted_, nosort
 
 
-def _lines_with_newlines(lines):
+def _lines_with_newlines(lines) -> Iterator[str]:
     for line in lines[0:-1]:
         yield line + "\n"
     yield lines[-1]
 
 
+def _mini_black_format(lines: List[str], line_length) -> Iterator[str]:
+    for line in lines:
+        if len(line) >= line_length:
+            from_imp_match = re.match(r"^(\s*)from (.+?) import (.+)", line)
+            if not from_imp_match:
+                yield line
+            else:
+                leading_whitespace = from_imp_match.group(1)
+                module = from_imp_match.group(2)
+                names = re.split(r", ", from_imp_match.group(3))
+                yield f"{leading_whitespace}from {module} import ("
+                for name in names:
+                    yield f"{leading_whitespace}    {name},"
+                yield ")"
+        else:
+            yield line
+
+
 def _read_python_source(filename):
     if filename == "-":
         file_content = sys.stdin.buffer.read()
@@ -896,6 +922,7 @@ def _run_file(options, filename):
         )
 
     if not options.statsonly:
+
         if options.diff:
             sys.stdout.writelines(
                 difflib.unified_diff(
@@ -920,10 +947,19 @@ def _run_file(options, filename):
 def run_with_options(options):
     for filename in options.filename:
         if os.path.isdir(filename):
-            for root, dirs, files in os.walk(filename):
-                for file in files:
-                    if file.endswith(".py") or file.endswith(".pyi"):
-                        _run_file(options, os.path.join(root, file))
 
+            def iter_files():
+                for root, dirs, files in os.walk(filename):
+                    for file in files:
+                        if file.endswith(".py") or file.endswith(".pyi"):
+                            yield os.path.join(root, file)
+
+            if options.workers is None or options.workers <= 1:
+                for file in iter_files():
+                    _run_file(options, file)
+            else:
+                func = partial(_run_file, options)
+                with Pool(options.workers) as pool:
+                    pool.map(func, iter_files())
         else:
             _run_file(options, filename)
